Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1275)

Unified Diff: Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/LayoutMultiColumnSpannerPlaceholder.h ('k') | Source/core/layout/LayoutObject.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp
diff --git a/Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp b/Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp
index 1a411f46902e6e9e8584d8d44a898910b85b659b..d072aa5e2f9071baf8dab713296ebd2d4c836bc3 100644
--- a/Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp
+++ b/Source/core/layout/LayoutMultiColumnSpannerPlaceholder.cpp
@@ -7,22 +7,22 @@
namespace blink {
-static void copyMarginProperties(LayoutStyle& placeholderStyle, const LayoutStyle& spannerStyle)
+static void copyMarginProperties(ComputedStyle& placeholderStyle, const ComputedStyle& spannerStyle)
{
// We really only need the block direction margins, but there are no setters for that in
// LayoutStyle. Just copy all margin sides. The inline ones don't matter anyway.
placeholderStyle.setMarginLeft(spannerStyle.marginLeft());
placeholderStyle.setMarginRight(spannerStyle.marginRight());
placeholderStyle.setMarginTop(spannerStyle.marginTop());
placeholderStyle.setMarginBottom(spannerStyle.marginBottom());
}
-LayoutMultiColumnSpannerPlaceholder* LayoutMultiColumnSpannerPlaceholder::createAnonymous(const LayoutStyle& parentStyle, LayoutBox& rendererInFlowThread)
+LayoutMultiColumnSpannerPlaceholder* LayoutMultiColumnSpannerPlaceholder::createAnonymous(const ComputedStyle& parentStyle, LayoutBox& rendererInFlowThread)
{
LayoutMultiColumnSpannerPlaceholder* newSpanner = new LayoutMultiColumnSpannerPlaceholder(&rendererInFlowThread);
Document& document = rendererInFlowThread.document();
newSpanner->setDocumentForAnonymous(&document);
- RefPtr<LayoutStyle> newStyle = LayoutStyle::createAnonymousStyleWithDisplay(parentStyle, BLOCK);
+ RefPtr<ComputedStyle> newStyle = ComputedStyle::createAnonymousStyleWithDisplay(parentStyle, BLOCK);
copyMarginProperties(*newStyle, rendererInFlowThread.styleRef());
newSpanner->setStyle(newStyle);
return newSpanner;
@@ -36,7 +36,7 @@ LayoutMultiColumnSpannerPlaceholder::LayoutMultiColumnSpannerPlaceholder(LayoutB
void LayoutMultiColumnSpannerPlaceholder::updateMarginProperties()
{
- RefPtr<LayoutStyle> newStyle = LayoutStyle::clone(styleRef());
+ RefPtr<ComputedStyle> newStyle = ComputedStyle::clone(styleRef());
copyMarginProperties(*newStyle, m_rendererInFlowThread->styleRef());
setStyle(newStyle);
}
@@ -7,22 +7,22 @@
{
// We really only need the block direction margins, but there are no setters for that in
- // LayoutStyle. Just copy all margin sides. The inline ones don't matter anyway.
+ // ComputedStyle. Just copy all margin sides. The inline ones don't matter anyway.
placeholderStyle.setMarginLeft(spannerStyle.marginLeft());
placeholderStyle.setMarginRight(spannerStyle.marginRight());
« no previous file with comments | « Source/core/layout/LayoutMultiColumnSpannerPlaceholder.h ('k') | Source/core/layout/LayoutObject.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698